==> mixinsdk-0.1.5.tar.gz: mixinsdk-0.1.5/README.md <==
# Mixin SDK for Python (Unofficial)

## Overview

This is the [Mixin Network](https://mixin.one) SDK for Python.

*Project objectives: ease of use and readability for developers.*

**It is still in development, please do not use it in production environment.**

## Getting started

> Runtime support: Python 3.9+

1. Clone the repository, or download code.

2. Set up and activate virtual environment, like this:

```bash
cd mixin-sdk-python-main
python3.9 -m venv env
. env/bin/activate
```

3. Install dependencies:

`python3.9 -m pip install -r requirements.txt`

4. Than see "examples" folder, and run it.

## Contributing

We'd love to accept your patches and contributions to this project.

How to contribute, see file [CONTRIBUTING.md](https://github.com/nodewee/mixin-sdk-python/blob/main/CONTRIBUTING.md)

Changelog see file [CHANGELOG.md](https://github.com/nodewee/mixin-sdk-python/blob/main/CHANGELOG.md)

**TODO**

- [ ] Address API
- [ ] Manage group API
- [ ] More messenger schema
- [ ] Circles API
- [ ] Upload Album
- [ ] Withdrawal API
- [ ] Multi-Signature API
- [ ] Collectibles API
- [ ] Mainnet RPC API and Client

## References

- <https://github.com/includeleec/mixin-python3-sdk>
- <https://github.com/learnforpractice/mixin-python>
- <https://developers.mixin.one/docs/api>
- <https://github.com/MixinNetwork/bot-api-go-client/>

## License

The project is licensed under the GNU GPL v3.0 - see the [LICENSE](https://github.com/nodewee/mixin-sdk-python/blob/main/LICENSE) file for details

==> mixinsdk-0.2.1.tar.gz: mixinsdk-0.2.1/README.md <==
# Mixin SDK for Python (Unofficial)

## Overview

This is the [Mixin Network](https://mixin.one) SDK for Python.

*Project objectives: ease of use and readability for developers.*

**Status**

This SDK is still considered a work in progress, therefore things might (and will) break with every update.

## Getting started

For sdk user:

```bash
pip install mixinsdk
```

For sdk dev:

> Runtime support: Python 3.9+

1. Clone the repository, or download code.

2. Set up and activate virtual environment, like this:

```bash
cd mixin-sdk-python-main
python3 -m venv .env
. .env/bin/activate

# for windows
# .\.env\Scripts\activate
```

3. Install dependencies:

`python3 -m pip install -r requirements.txt`

4. Than see "examples" folder, and run it.

## Relations

Mixin Messenger Bot Boilerplate: [nodewee/mm-bot-boilerplate](https://github.com/nodewee/mm-bot-boilerplate)

## Contributing

We'd love to accept your patches and contributions to this project.

How to contribute, see file [CONTRIBUTING.md](https://github.com/nodewee/mixin-sdk-python/blob/main/CONTRIBUTING.md)

Changelog see file [CHANGELOG.md](https://github.com/nodewee/mixin-sdk-python/blob/main/CHANGELOG.md)

**TODO**

- [ ] Support for send encrypted messages?
- [ ] Address API
- [ ] Circles API
- [ ] Upload Album
- [ ] Withdrawal API
- [ ] Multi-Signature API
- [ ] Collectibles API
- [ ] Mainnet RPC API and Client

## References

- <https://developers.mixin.one/docs/api>
- <https://github.com/MixinNetwork/bot-api-go-client/>
- <https://github.com/includeleec/mixin-python3-sdk>
- <https://github.com/learnforpractice/mixin-python>

## License

The project is licensed under the MIT License - see the [LICENSE](https://github.com/nodewee/mixin-sdk-python/blob/main/LICENSE) file for details.
